import React, { useEffect, useState } from "react";
import { useSelector, useDispatch } from "react-redux";
import {
  CCloseButton,
  CSidebar,
  CSidebarBrand,
  CSidebarFooter,
  CSidebarHeader,
  CSidebarToggler,
  CSidebarNav,
} from "@coreui/react";
import CIcon from "@coreui/icons-react";

import { AppSidebarNav } from "./AppSidebarNav";

import { logoNegative } from "src/assets/brand/logo-negative";
import { sygnet } from "src/assets/brand/sygnet";

import SimpleBar from "simplebar-react";
import "simplebar-react/dist/simplebar.min.css";
// import "simplebar/dist/simplebar.min.css";

// sidebar nav config
import navigation from "../_nav";
import { isAutheticated } from "src/auth";
import axios from "axios";
import { Link } from "react-router-dom";

const AppSidebar = () => {
  const dispatch = useDispatch();
  const unfoldable = useSelector((state) => state.sidebarUnfoldable);
  const sidebarShow = useSelector((state) => state.sidebarShow);
  const [navigationItem, setNavigationItem] = useState(navigation);

  const [userdata, setUserData] = useState(null);
  const token = isAutheticated();
  // console.log("userDatt", userdata);

  useEffect(() => {
    const getUser = async () => {
      let existanceData = localStorage.getItem("authToken");
      if (!existanceData) {
        // console.log(existanceData.userData)
        setUserData(false);
      } else {
        try {
          // console.log('requesting user data from server')
          let response = await axios.get(`/api/v1/user/details`, {
            headers: {
              Authorization: `Bearer ${token}`,
            },
          });
          // console.log(response.data)
          const data = response.data;
          if (
            (data.success && data.user.role === "admin") ||
            data.user.role === "Employee"
          ) {
            setUserData(data.user);
          } else {
            setUserData(false);
          }
        } catch (err) {
          setUserData(false);
          console.log(err);
        }
      }
    };
    getUser();
  }, []);
  useEffect(() => {
    if (userdata && userdata.accessTo) {
      const filteredNavigation = navigation.filter((item) => {
        if (userdata.accessTo[item.name]) {
          return true;
        }
        return false;
      });
      setNavigationItem(filteredNavigation);
    } else {
      setNavigationItem(navigation);
    }
  }, [userdata]);

  ///----------------------//
  const [loading, setLoading] = useState(false);

  // urlcreated images
  const [AppName, setAppName] = useState("");
  const [HeaderlogoUrl, setHeaderlogoUrl] = useState("");
  const [FooterlogoUrl, setFooterlogoUrl] = useState("");
  const [AdminlogoUrl, setAdminlogoUrl] = useState("");

  useEffect(() => {
    async function getConfiguration() {
      const configDetails = await axios.get(`/api/config`, {
        headers: {
          Authorization: `Bearer ${token}`,
        },
      });
      setAppName(configDetails.data.result[0]?.appName);
      configDetails.data.result.map((item) => {
        setHeaderlogoUrl(item?.logo[0]?.Headerlogo);
        setFooterlogoUrl(item?.logo[0]?.Footerlogo);
        setAdminlogoUrl(item?.logo[0]?.Adminlogo);
      });
    }
    getConfiguration();
  }, []);

  //---------------------------//
  return (
    <CSidebar
      className="border-end"
      colorScheme="dark"
      position="fixed"
      unfoldable={unfoldable}
      visible={sidebarShow}
      style={{ background: "#179FAF" }}
      onVisibleChange={(visible) => {
        dispatch({ type: "set", sidebarShow: visible });
      }}
    >
      {/* <CSidebarHeader> */}
      {/* <CSidebarBrand
          // className="d-none  d-md-flex"
          // style={{ background: "rgb(140, 213, 213)" }}
          to="/"
        > */}
      {/* <CIcon className="sidebar-brand-full" icon={logoNegative} height={35} /> */}

      {/* {AdminlogoUrl ? (
            <Link to="/dashboard">
              <img src={AdminlogoUrl} alt="" height={32} style={{borderRadius:"5px"}} />
            </Link>
          ) : { AppName } ? (
            <h3>Cheminova </h3>
          ) : (
            ""
          )} */}
      {/* <CIcon className="sidebar-brand-narrow"  height={35} /> */}
      {/* <CIcon className="sidebar-brand-narrow" icon={sygnet} height={32} /> */}
      {/* </CSidebarBrand> */}
      {/* <CCloseButton
          className="d-lg-none"
          dark
          onClick={() => dispatch({ type: 'set', sidebarShow: false })}
        /> */}
      {/* </CSidebarHeader> */}
      <CSidebarHeader
        style={{
          display: "flex",
          alignItems: "center",
          justifyContent: "center",
          padding: "0.5rem",
        }}
      >
        {AdminlogoUrl ? (
          <Link to="/dashboard">
            <img
              src={AdminlogoUrl}
              alt="Admin Logo"
              style={{
                width: "100%",
                height: "100%",
                objectFit: "contain",
                borderRadius: "5px",
              }}
            />
          </Link>
        ) : AppName ? (
          <h3>Cheminova</h3>
        ) : (
          ""
        )}
      </CSidebarHeader>

      {/* <CSidebarNav>
        <SimpleBar>
          <AppSidebarNav items={navigationItem}/>
        </SimpleBar>
      </CSidebarNav> */}
      <CSidebarNav>
        <SimpleBar>
          <div
            style={{
              background: "#B4D1E5",
              margin: "0.5rem",
              border: "none",
              borderRadius: "20px",
            }}
          >
            <AppSidebarNav items={navigation} />
          </div>
        </SimpleBar>
      </CSidebarNav>
      <CSidebarFooter className="border-top">
        <div className="d-flex flex-column justify-content-center align-items-center h-100">
          <span className="text-muted">Powered by</span>
          <a
            href="https://codeology.solutions/"
            target="_blank"
            // rel="noopener noreferrer"
            className="fw-semibold text-muted"
          >
            Codeology.solutions
          </a>
        </div>

        {/* <CSidebarToggler
          onClick={() => dispatch({ type: 'set', sidebarUnfoldable: !unfoldable })}
        /> */}
      </CSidebarFooter>
      {/* <CSidebarToggler
        className="d-none d-lg-flex"
        onClick={() =>
          dispatch({ type: "set", sidebarUnfoldable: !unfoldable })
        }
      /> */}
    </CSidebar>
  );
};

export default React.memo(AppSidebar);
