import React, { useState, useEffect } from "react";
import axios from "axios";
import {
  Box,
  Typography,
  Grid,
  Paper,
  IconButton,
  Table,
  TableBody,
  TableCell,
  TableContainer,
  TableHead,
  TableRow,
  Paper as MuiPaper,
} from "@mui/material";
import { useParams, useNavigate } from "react-router-dom";
import { isAutheticated } from "../../auth";
import CancelIcon from "@mui/icons-material/Cancel"; // Add this import

const SingleSales = () => {
  const { id } = useParams();
  const [SalesDetails, setSalesDetails] = useState(null);
  const token = isAutheticated();
  const navigate = useNavigate();

  useEffect(() => {
    const fetchData = async () => {
      try {
        const response = await axios.get(`/api/sales/${id}`, {
          headers: {
            "Access-Control-Allow-Origin": "*",
            Authorization: `Bearer ${token}`,
            "Content-Type": "application/json",
          },
        });
        setSalesDetails(response.data);
        // console.log("Inventory Details: ", response.data);
      } catch (error) {
        console.error("Error fetching data: ", error);
      }
    };

    fetchData();
  }, [id]);

  const handleCancel = () => {
    navigate("/inventory");
  };

  if (!SalesDetails) {
    return <Typography>Loading...</Typography>;
  }

  return (
    <Box sx={{ p: 3 }}>
      <Box
        sx={{
          display: "flex",
          justifyContent: "space-between",
          alignItems: "center",
          mb: 3,
        }}
      >
        <Typography variant="h4">Sales Details</Typography>
        <IconButton sx={{ color: "red" }} onClick={handleCancel}>
          <CancelIcon />
        </IconButton>
      </Box>

      <Paper sx={{ p: 2, mb: 3 }}>
        <Typography variant="h5" gutterBottom>
          Sales Data
        </Typography>
        <Grid container spacing={2}>
          <Grid item xs={12}>
            <Typography>
              <strong>Timestamp:</strong>{" "}
              {new Date(SalesDetails.createdAt).toLocaleString("en-IN", {
                weekday: "short",
                month: "short",
                day: "numeric",
                year: "numeric",
                hour: "numeric",
                minute: "numeric",
                hour12: true,
              })}
            </Typography>
          </Grid>
        </Grid>
      </Paper>

      <Paper sx={{ p: 2, mb: 3 }}>
        <Typography variant="h6" gutterBottom>
          Product Details
        </Typography>
        <TableContainer component={MuiPaper}>
          <Table>
            <TableHead >
              <TableRow>
                <TableCell><strong>Product Name</strong></TableCell>
                <TableCell><strong>SKU</strong></TableCell>
                <TableCell><strong>QuantitySold</strong></TableCell>
                <TableCell><strong>SalesAmount</strong></TableCell>
              </TableRow>
            </TableHead>
            <TableBody>
              {SalesDetails.products.map((product, index) => (
                <TableRow key={index}>
                  <TableCell>{product.ProductName}</TableCell>
                  <TableCell>{product.SKU}</TableCell>
                  <TableCell>{product.QuantitySold}</TableCell>
                  <TableCell>{product.SalesAmount}</TableCell>
                </TableRow>
              ))}
            </TableBody>
          </Table>
        </TableContainer>
      </Paper>

      <Paper sx={{ p: 2, mb: 3 }}>
        <Typography variant="h6" gutterBottom>
          Data Added For
        </Typography>
        <Grid container spacing={2}>
          <Grid item xs={6}>
            <Typography>
              <strong>PD or Retailer:</strong>{" "}
              {SalesDetails.addedFor}
            </Typography>
            <Typography>
              <strong>Name:</strong> {SalesDetails.addedForData.name}
            </Typography>
            <Typography>
              <strong>Mobile Number:</strong>{" "}
              {SalesDetails.addedForData.phone || SalesDetails.addedForData.mobile_number}
            </Typography>
            <Typography>
              <strong>Email:</strong> {SalesDetails.addedForData.email||'N/A'}
            </Typography>
            <Typography>
              <strong>Trade Name:</strong>{" "}
              {SalesDetails.addedForData.shippingAddress?.tradeName||SalesDetails.addedForData.kyc.trade_name}
            </Typography>
          </Grid>
        </Grid>
      </Paper>

      <Paper sx={{ p: 2, mb: 3 }}>
        <Typography variant="h6" gutterBottom>
          Data Entered By
        </Typography>
        <Grid container spacing={2}>
          <Grid item xs={6}>
            <Typography>
              <strong>Designation:</strong> {SalesDetails.userType}
            </Typography>
            <Typography>
              <strong>Name:</strong> {SalesDetails.user?.name}
            </Typography>
            <Typography>
              <strong>ID:</strong> {SalesDetails.user?.uniqueId}
            </Typography>
            <Typography>
              <strong>Email:</strong> {SalesDetails.user?.email}
            </Typography>
            <Typography>
              <strong>Mobile Number:</strong>{" "}
              {SalesDetails.user?.mobileNumber}
            </Typography>
          </Grid>
        </Grid>
      </Paper>
    </Box>
  );
};

export default SingleSales;
