import React, { useState, useEffect, useRef, useCallback } from "react";
import { Link } from "react-router-dom";
import axios from "axios";
import { isAutheticated } from "src/auth";
import swal from "sweetalert";
import debounce from "lodash.debounce";

const Tasks = () => {
  const token = isAutheticated();
  const [loading, setLoading] = useState(false);
  const [taskData, settaskData] = useState([]);

  const tmnameRef = useRef();
  const scnameRef = useRef();
  const statusnameRef = useRef();
  const startDateRef = useRef();
  const endDateRef = useRef();

  const [currentPage, setCurrentPage] = useState(1);
  const [itemPerPage, setItemPerPage] = useState(10);
  const [totalData, setTotalData] = useState(0);

  const gettaskData = async () => {
    setLoading(true);
    try {
      const response = await axios.get(`/api/task/tasks`, {
        headers: {
          Authorization: `Bearer ${token}`,
        },
        params: {
          page: currentPage,
          show: itemPerPage,
          startDate: startDateRef.current?.value || "",
          endDate: endDateRef.current?.value || "",
          TMname: tmnameRef.current?.value || "",
          SCname: scnameRef.current?.value || "",
          status: statusnameRef.current?.value || "",
        },
      });
      // console.log("response", response);

      settaskData(response.data?.data || []);
      setTotalData(response.data?.pagination?.total || 0);
    } catch (err) {
      const msg = err?.response?.data?.msg || "Something went wrong!";
      swal({
        title: "Error",
        text: msg,
        icon: "error",
        button: "Retry",
        dangerMode: true,
      });
    } finally {
      setLoading(false);
    }
  };

  const debouncedSearch = useCallback(
    debounce(() => {
      setCurrentPage(1);
      gettaskData();
    }, 500),
    []
  );

  const handleSearchChange = () => {
    debouncedSearch();
  };

  useEffect(() => {
    gettaskData();
  }, [itemPerPage, currentPage]);

  return (
    <div className="main-content">
      <div className="page-content">
        <div className="container-fluid">
          <div className="row">
            <div className="col-12">
              <div
                className="
                    page-title-box
                    d-flex
                    align-items-center
                    justify-content-between
                  "
              >
                <div style={{ fontSize: "22px" }} className="fw-bold">
                  Task List
                </div>
              </div>
            </div>
          </div>

          <div className="row">
            <div className="col-lg-12">
              <div className="card">
                <div className="card-body">
                  <div className="row ml-0 mr-0 mb-10">
                    <div className="col-lg-1 col-md-2 col-6">
                      <div className="dataTables_length">
                        <label className="w-100">
                          Show
                          <select
                            onChange={(e) => {
                              setItemPerPage(e.target.value);
                              setCurrentPage(1);
                            }}
                            className="form-control"
                            disabled={loading}
                          >
                            <option value="10">10</option>
                            <option value="25">25</option>
                            <option value="50">50</option>
                            <option value="100">100</option>
                          </select>
                          entries
                        </label>
                      </div>
                    </div>
                    <div className="col-lg-3 col-md-5 col-12">
                      <label>TM Name:</label>
                      <input
                        type="text"
                        placeholder="TM name"
                        className="form-control"
                        ref={tmnameRef}
                        onChange={handleSearchChange}
                        disabled={loading}
                      />
                    </div>
                    <div className="col-lg-3 col-md-5 col-12">
                      <label>SC Name:</label>
                      <input
                        type="text"
                        placeholder="SC name"
                        className="form-control"
                        ref={scnameRef}
                        onChange={handleSearchChange}
                        disabled={loading}
                      />
                    </div>
                    <div className="col-lg-2 col-md-4 col-4">
                      <label>Start Date:</label>
                      <input
                        type="date"
                        className="form-control"
                        ref={startDateRef}
                        onChange={handleSearchChange}
                        disabled={loading}
                      />
                    </div>
                    <div className="col-lg-2 col-md-4 col-4">
                      <label>End Date:</label>
                      <input
                        type="date"
                        className="form-control"
                        ref={endDateRef}
                        onChange={handleSearchChange}
                        disabled={loading}
                      />
                    </div>
                    <div className="col-lg-1 col-md-4 col-4">
                      <label>Status:</label>
                      <select
                        className="form-control"
                        ref={statusnameRef}
                        onChange={handleSearchChange}
                        disabled={loading}
                      >
                        <option value="">All</option>
                        <option value="New">New</option>
                        <option value="Pending">Pending</option>
                        <option value="Completed">Completed</option>
                      </select>
                    </div>
                  </div>

                  <style jsx>{`
                    @media (max-width: 1200px) {
                      .col-lg-1 {
                        flex: 0 0 20%;
                        max-width: 20%;
                      }
                      .col-lg-2 {
                        flex: 0 0 37%;
                        max-width: 37%;
                      }
                      .col-lg-3 {
                        flex: 0 0 40%;
                        max-width: 40%;
                      }
                    }
                    @media (max-width: 768px) {
                      .col-lg-1,
                      .col-lg-2,
                      .col-lg-3,
                      .col-md-2,
                      .col-md-4,
                      .col-md-5,
                      .col-4,
                      .col-6,
                      .col-12 {
                        flex: 0 0 100%;
                        max-width: 100%;
                      }
                    }
                  `}</style>

                  <div className="table-responsive table-shoot mt-3">
                    <table
                      className="table table-centered table-nowrap"
                      style={{
                        border: "1px solid",
                        borderCollapse: "collapse",
                      }} // Ensure borders collapse for clean lines
                    >
                      <thead
                        className="thead-light"
                        style={{ background: "#ecdddd" }}
                      >
                        <tr>
                          <th
                            className="text-start"
                            style={{ border: "1px solid" }}
                          >
                            Task ID
                          </th>
                          <th
                            className="text-start"
                            style={{ border: "1px solid" }}
                          >
                            Task Assigned Date
                          </th>
                          <th
                            className="text-start"
                            style={{ border: "1px solid" }}
                          >
                            Assigned TM
                          </th>
                          <th
                            className="text-start"
                            style={{ border: "1px solid" }}
                          >
                            Task Type
                          </th>
                          <th
                            className="text-start"
                            style={{ border: "1px solid" }}
                          >
                            Sales Coordinator
                          </th>
                          <th
                            className="text-start"
                            style={{ border: "1px solid" }}
                          >
                            Due Date
                          </th>
                          <th
                            className="text-start"
                            style={{ border: "1px solid" }}
                          >
                            Task Status
                          </th>
                        </tr>
                      </thead>

                      <tbody>
                        {loading ? (
                          <tr>
                            <td
                              className="text-center"
                              colSpan="6"
                              style={{ border: "1px solid" }}
                            >
                              Loading...
                            </td>
                          </tr>
                        ) : taskData.length > 0 ? (
                          taskData.map((task, index) => (
                            <tr key={index}>
                              <td
                                className="text-start"
                                style={{ border: "1px solid" }}
                              >
                                {task.taskId}
                              </td>
                              <td
                                className="text-start"
                                style={{ border: "1px solid" }}
                              >
                                {new Date(task.createdAt).toLocaleString(
                                  "en-IN",
                                  {
                                    month: "short",
                                    day: "numeric",
                                    year: "numeric",
                                  }
                                )}
                              </td>
                              <td
                                className="text-start"
                                style={{ border: "1px solid" }}
                              >
                                {task.taskAssignedBy.name}
                              </td>
                              <td
                                className="text-start"
                                style={{ border: "1px solid" }}
                              >
                                {task.task}
                              </td>
                              <td
                                className="text-start"
                                style={{ border: "1px solid" }}
                              >
                                {task.taskAssignedTo.name}
                              </td>
                              <td
                                className="text-start"
                                style={{ border: "1px solid" }}
                              >
                                {new Date(task.taskDueDate).toLocaleString(
                                  "en-IN",
                                  {
                                    month: "short",
                                    day: "numeric",
                                    year: "numeric",
                                  }
                                )}
                              </td>
                              <td
                                className="text-start"
                                style={{ border: "1px solid" }}
                              >
                                {task.taskStatus}
                              </td>
                            </tr>
                          ))
                        ) : (
                          <tr className="text-center">
                            <td colSpan="6" style={{ border: "1px solid" }}>
                              <h5>No Data Available...</h5>
                            </td>
                          </tr>
                        )}
                      </tbody>
                    </table>
                  </div>
                  <div className="row mt-20">
                    <div className="col-sm-12 col-md-6 mb-20">
                      <div
                        className="dataTables_info"
                        id="datatable_info"
                        role="status"
                        aria-live="polite"
                      >
                        Showing {currentPage * itemPerPage - itemPerPage + 1} to{" "}
                        {Math.min(currentPage * itemPerPage, totalData)} of{" "}
                        {totalData} entries
                      </div>
                    </div>

                    <div className="col-sm-12 col-md-6">
                      <div className="d-flex">
                        <ul className="pagination ms-auto">
                          <li
                            className={
                              currentPage === 1
                                ? "paginate_button page-item previous disabled"
                                : "paginate_button page-item previous"
                            }
                          >
                            <span
                              className="page-link"
                              style={{ cursor: "pointer" }}
                              onClick={() => setCurrentPage((prev) => prev - 1)}
                              disabled={loading}
                            >
                              Previous
                            </span>
                          </li>

                          {!(currentPage - 1 < 1) && (
                            <li className="paginate_button page-item">
                              <span
                                className="page-link"
                                style={{ cursor: "pointer" }}
                                onClick={(e) =>
                                  setCurrentPage((prev) => prev - 1)
                                }
                                disabled={loading}
                              >
                                {currentPage - 1}
                              </span>
                            </li>
                          )}

                          <li className="paginate_button page-item active">
                            <span
                              className="page-link"
                              style={{ cursor: "pointer" }}
                            >
                              {currentPage}
                            </span>
                          </li>

                          {!(
                            (currentPage + 1) * itemPerPage - itemPerPage >
                            totalData - 1
                          ) && (
                            <li className="paginate_button page-item ">
                              <span
                                className="page-link"
                                style={{ cursor: "pointer" }}
                                onClick={() => {
                                  setCurrentPage((prev) => prev + 1);
                                }}
                                disabled={loading}
                              >
                                {currentPage + 1}
                              </span>
                            </li>
                          )}

                          <li
                            className={
                              !(
                                (currentPage + 1) * itemPerPage - itemPerPage >
                                totalData - 1
                              )
                                ? "paginate_button page-item next"
                                : "paginate_button page-item next disabled"
                            }
                          >
                            <span
                              className="page-link"
                              style={{ cursor: "pointer" }}
                              onClick={() => setCurrentPage((prev) => prev + 1)}
                              disabled={loading}
                            >
                              Next
                            </span>
                          </li>
                        </ul>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default Tasks;
